pub struct Journalist { /* private fields */ }Expand description
Journalists: ingredients. Journalists have a signing/verifying key, a reply key, a fetch key, and a collection of one-time signed key bundles
Implementations
Sourceimpl Journalist
impl Journalist
pub fn new<R: RngCore + CryptoRng>(rng: &mut R, num_keybundles: usize) -> Self
pub fn public(&self, idx: usize) -> JournalistPublicView
Sourcepub fn long_term_bytes(&self) -> JournalistLongTermBytes
pub fn long_term_bytes(&self) -> JournalistLongTermBytes
Extract the long-term keypairs as raw bytes, sufficient to
reconstruct the long-term Journalist state via
Journalist::from_long_term_bytes.
Sourcepub fn from_long_term_bytes(parts: JournalistLongTermBytes) -> Self
pub fn from_long_term_bytes(parts: JournalistLongTermBytes) -> Self
Reconstruct the long-term Journalist state from raw key bytes.
Sourcepub fn generate_ephemeral_bundles<R: RngCore + CryptoRng>(
&mut self,
rng: &mut R,
n: usize,
)
pub fn generate_ephemeral_bundles<R: RngCore + CryptoRng>( &mut self, rng: &mut R, n: usize, )
Generate n fresh signed ephemeral key bundles and retain them in memory.
The public halves are uploaded to the server via
create_ephemeral_key_request.
The secret halves should be persisted via Journalist::ephemeral_bundle_bytes.
Sourcepub fn ephemeral_bundle_bytes(&self) -> Vec<EphemeralBundleBytes>
pub fn ephemeral_bundle_bytes(&self) -> Vec<EphemeralBundleBytes>
Extract the secret halves of the retained ephemeral key bundles so we can
reconstruct them via Journalist::load_ephemeral_bundles.
Used by the demo.
Sourcepub fn load_ephemeral_bundles(&mut self, bundles: Vec<EphemeralBundleBytes>)
pub fn load_ephemeral_bundles(&mut self, bundles: Vec<EphemeralBundleBytes>)
Reconstruct ephemeral key bundles from persisted secret bytes.
Used by the demo